#include <iostream>
#include <stdio.h>
#include <unistd.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include "jblib.h"

void usage()
{
    cout << "Usage: jbflash [IP ADDRESS] [FILE]" << endl;
    cout << "Write configuration file to JTAG-Blazer's flash memory" << endl;
    cout << " -h,\tshow this message" << endl;
    cout << " -c,\tcompressed file" << endl;
    cout << " -l,\tTE7720 mode" << endl;
}

int main(int argc, char** argv)
{
	FlashFileData fileData;
	memset(&fileData, 0, sizeof(fileData));

	int opt;
	while((opt = getopt(argc, argv, "hlc")) != -1){
		switch(opt){
		case 'l':
			fileData.littleBear = true;
			break;
		case 'c':
			fileData.compressed = true;
			break;
		case 'h':
			usage();
			return 0;
		default:
			usage();
			return -1;
		}
	}

	int argPos = optind;
	if(argPos >= argc){
		cerr << argv[0] << ": IP address is not specified" << endl;
		usage();
		return -1;
	}
	in_addr addr;
	if(!inet_aton(argv[optind], &addr)){
		cerr << argv[0] << ": Invalid IP address" << endl;
		usage();
		return -1;
	}

	argPos++;
	if(argPos >= argc){
		cerr << argv[0] << ": FILE is not specified" << endl;
		usage();
		return -1;
	}
	const char* fileName = argv[argPos];

	fileData.recordTime = time(NULL);

	CJBLib lib(addr.s_addr);
	CJBLib::ErrorCode errCode = lib.FlashWriteRequest(argv[2], &fileData, NULL);

	if(errCode != CJBLib::JTAG_NO_ERROR)
		fprintf(stderr, "Failed (code : %08x)\n", (int)errCode);

	return (int)errCode;
}
