#include <iostream>
#include <stdio.h>
#include <unistd.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include "jblib.h"

void usage()
{
	cout << "Usage: jbsetspeed [IP ADDRESS] [SPPED] [OPTION]" << endl;
	cout << "Set JTAG link clock speed of JTAG-Blazer" << endl;
	cout << "SPEED must be between 0(12.9MHz) - 6(0.2MHz)" << endl;
	cout << " -l,\tshow SPEED list" << endl;
	cout << " -h,\tshow this message" << endl;
}

void speedlist()
{
	cout << "JTAG configuration clock list [MHz]" << endl;
	cout << "0 : 12.90" << endl;
	cout << "1 :  6.45" << endl;
	cout << "2 :  3.22" << endl;
	cout << "3 :  1.61" << endl;
	cout << "4 :  0.80" << endl;
	cout << "5 :  0.40" << endl;
	cout << "6 :  0.20" << endl;
}

int main(int argc, char** argv)
{
	int opt;
	while((opt = getopt(argc, argv, "hl")) != -1){
		switch(opt){
		case 'l':
			speedlist();
			return 0;
		case 'h':
			usage();
			return 0;
		default:
			usage();
			return -1;
		}
	}

	int argPos = optind;
	if(argPos >= argc){
		cerr << argv[0] << ": IP address is not specified" << endl;
		usage();
		return -1;
	}
    in_addr addr;
	if(!inet_aton(argv[optind], &addr)){
		cerr << argv[0] << ": Invalid IP address" << endl;
		usage();
		return -1;
	}

	argPos++;
	if(argPos >= argc){
		cerr << argv[0] << ": JTAG clock is not specified" << endl;
		usage();
		return -1;
	}
	unsigned char speed = argv[argPos][0] - '0';
	if(speed > 6){
		cerr << argv[0] << ": invlied speed value (" << speed << ")" << endl;
		return -1;
	}

	CJBLib lib(addr.s_addr);
	CJBLib::ErrorCode errCode = lib.ChangeTransferRateRequest(speed);

	if(errCode != CJBLib::JTAG_NO_ERROR)
		fprintf(stderr, "Failed (code : %08x)\n", (int)errCode);

	return (int)errCode;
}
