#include <iostream>
#include <stdio.h>
#include <unistd.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include "jblib.h"

void usage()
{
	cout << "Usage: jbtarget [IP ADDRESS] [FILE]" << endl;
	cout << "Write configuration file to target board connected to JTAG-Blazer" << endl;
	cout << " -h,\tshow this message" << endl;
	cout << " -l,\tTE7720 mode" << endl;
}

int main(int argc, char** argv)
{
	bool littlebear = false;
    int opt;
	while((opt = getopt(argc, argv, "hl")) != -1){
		switch(opt){
		case 'l':
			littlebear = true;
			break;
		case 'h':
			usage();
			return 0;
		default:
			usage();
			return -1;
		}
	}

	int argPos = optind;
	if(argPos >= argc){
		cerr << argv[0] << ": IP address is not specified" << endl;
		usage();
		return -1;
	}

	in_addr addr;
    if(!inet_aton(argv[optind], &addr)){
		cerr << argv[0] << ": Invalid IP address" << endl;
		usage();
		return -1;
	}

    argPos++;
	if(argPos >= argc){
		cerr << argv[0] << ": FILE is not specified" << endl;
		usage();
		return -1;
	}
    const char* fileName = argv[argPos];

	CJBLib lib(addr.s_addr);
	CJBLib::ErrorCode errCode = lib.TargetWriteRequest(
									fileName, littlebear, NULL);

	if(errCode != CJBLib::JTAG_NO_ERROR)
		fprintf(stderr, "Failed (code : %08x)\n", (int)errCode);

	return (int)errCode;
}
